/*
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

/*
 * Name:    d_naout.h
 *
 * Purpose: Header file for MX network analog output devices.
 */

#ifndef __D_NAOUT_H__
#define __D_NAOUT_H__

#include "mx_aout.h"

typedef struct {
	MX_RECORD *server_record;
	char remote_record_name[ MXU_RECORD_NAME_LENGTH+1 ];
} MX_NETWORK_AOUTPUT;

/* Define all of the interface functions. */

MX_API mx_status_type mxd_network_aoutput_initialize_type( long type );
MX_API mx_status_type mxd_network_aoutput_create_record_structures(
							MX_RECORD *record );
MX_API mx_status_type mxd_network_aoutput_finish_record_initialization(
							MX_RECORD *record );
MX_API mx_status_type mxd_network_aoutput_delete_record( MX_RECORD *record );
MX_API mx_status_type mxd_network_aoutput_print_structure( FILE *file,
							MX_RECORD *record );
MX_API mx_status_type mxd_network_aoutput_read_parms_from_hardware(
							MX_RECORD *record );
MX_API mx_status_type mxd_network_aoutput_write_parms_to_hardware(
							MX_RECORD *record );
MX_API mx_status_type mxd_network_aoutput_open( MX_RECORD *record );
MX_API mx_status_type mxd_network_aoutput_close( MX_RECORD *record );

MX_API mx_status_type mxd_network_aoutput_read( MX_ANALOG_OUTPUT *aoutput );
MX_API mx_status_type mxd_network_aoutput_write( MX_ANALOG_OUTPUT *aoutput );

extern MX_RECORD_FUNCTION_LIST mxd_network_aoutput_record_function_list;
extern MX_ANALOG_OUTPUT_FUNCTION_LIST
			mxd_network_aoutput_analog_output_function_list;

extern long mxd_network_aoutput_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxd_network_aoutput_rfield_def_ptr;

#define MXD_NETWORK_AOUTPUT_STANDARD_FIELDS \
  {-1, -1, "server_record", MXFT_RECORD, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_NETWORK_AOUTPUT, server_record), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY) }, \
  \
  {-1, -1, "remote_record_name", MXFT_STRING, \
	NULL, 1, {MXU_RECORD_NAME_LENGTH}, \
     MXF_REC_TYPE_STRUCT, offsetof(MX_NETWORK_AOUTPUT, remote_record_name), \
	{sizeof(char)}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY) }

#endif /* __D_NAOUT_H__ */

