/*
 * Name:     mx_drivr.h
 *
 * Purpose:  Contains the preprocessor symbols defining all the MX class
 *           and device types.
 *
 * Notes:    Each site is expected to add any special classes defined at
 *           that site.
 *
 *           Also, do _not_ rely on the numerical value of the #defines
 *           in this file.  They have changed before and may change again.
 *           If you need to save type information in a file, the preferred
 *           mechanism is to use the MX_DRIVER lists to convert the
 *           numerical value back to a text string that can be saved
 *           in a file.
 *
 *--------------------------------------------------------------------------
 *
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __MX_DRIVR_H__
#define __MX_DRIVR_H__

#include "mx_rec.h"

MX_API MX_DRIVER mx_superclass_list[];
MX_API MX_DRIVER mx_class_list[];
MX_API MX_DRIVER mx_type_list[];

MX_API MX_DRIVER *mx_list_of_types[];

/* The following is a list of currently supported server protocols.
 * The protocol values are ORed together to form the value of the field
 * server_protocols_active in the MX_LIST_HEAD structure for the list.
 * This means that the values must be powers of 2.
 *
 * For a client or standalone program, server_protocols_active will normally
 * be set to zero.
 */

#define MXPROT_MX		1

/* The following three defines are used to select the level of a record. */

/* It is important that MXR_ALL be defined specifically as (-1), since
 * the savefile record classes are listed as bitmasks below.
 */

#define MXR_ALL			(-1)	/* any superclass */
#define MXC_ALL			(-2)	/* any class */
#define MXT_ALL			(-3)	/* any type */

/* --- Superclasses --- */

#define MXR_LIST_HEAD			1
#define MXR_INTERFACE			2
#define MXR_DEVICE			3
#define MXR_SCAN			4
#define MXR_VARIABLE			5
#define MXR_SERVER			6
#define MXR_SPECIAL			7

#define MXR_PLACEHOLDER			32768


/* --- Interface classes --- */

#define MXI_RS232			1
#define MXI_GPIB   			2
#define MXI_CAMAC			3
#define MXI_GENERIC			4
#define MXI_PORTIO			5
#define MXI_MMIO			6

/* --- Device classes --- */

#define MXC_ANALOG_INPUT		21
#define MXC_ANALOG_OUTPUT		22
#define MXC_DIGITAL_INPUT		23
#define MXC_DIGITAL_OUTPUT		24
#define MXC_MOTOR			25
#define MXC_ENCODER			26
#define MXC_SCALER			27
#define MXC_TIMER			28
#define MXC_AMPLIFIER			29
#define MXC_RELAY			30
#define MXC_MULTICHANNEL_ANALYZER	31
#define MXC_MULTICHANNEL_SCALER		32

/* --- Scan classes --- */

#define MXS_LINEAR_SCAN			41
#define MXS_LIST_SCAN			42
#define MXS_XAFS_SCAN			43
#define MXS_QUICK_SCAN			44

/* --- Variable classes --- */

#define MXV_INLINE			51
#define MXV_NETWORK			52
#define MXV_EPICS			53

/* --- Server classes --- */

#define MXN_NETWORK_SERVER		61

/* --- Special classes --- */

#define MXZ_GROUP			71

/* --- Interface types --- */

#define MXI_232_SOFTWARE		100
#define MXI_232_TTY			101
#define MXI_232_COM			102
#define MXI_232_FOSSIL			103
#define MXI_232_KS3344			104
#define MXI_232_WIN32COM		105
#define MXI_232_TCP232			106

#define MXI_GPIB_SOFTWARE		200
#define MXI_GPIB_NI			201
#define MXI_GPIB_K500SERIAL		202

#define MXI_CAM_SOFTWARE		300
#define MXI_CAM_DSP6001			301

#define MXI_GEN_MM3000			400
#define MXI_GEN_MM4000			401
#define MXI_GEN_PMAC			402
#define MXI_GEN_COMPUMOTOR		403
#define MXI_GEN_ORTEC974		404
#define MXI_GEN_GGCS			405
#define MXI_GEN_UMCBI			406
#define MXI_GEN_D8			407
#define MXI_GEN_PDI40			408
#define MXI_GEN_PDI45			409
#define MXI_GEN_VP9000			410
#define MXI_GEN_8255			411
#define MXI_GEN_AM9513			412
#define MXI_GEN_HSC1			413

#define MXI_PIO_PORTIO			500
#define MXI_PIO_DOS			501

/* --- Analog input types --- */

#define MXT_AIN_SOFTWARE		10000
#define MXT_AIN_KS3512			10001
#define MXT_AIN_PDI45			10002
#define MXT_AIN_LABPC			10003
#define MXT_AIN_EPICS			10004
#define MXT_AIN_NETWORK			10005

/* --- Analog output types --- */

#define MXT_AOU_SOFTWARE		20000
#define MXT_AOU_KS3112			20001
#define MXT_AOU_PDI45			20002
#define MXT_AOU_LABPC			20003
#define MXT_AOU_EPICS			20004
#define MXT_AOU_NETWORK			20005

/* --- Digital input types --- */

#define MXT_DIN_SOFTWARE		30000
#define MXT_DIN_KS3063			30001
#define MXT_DIN_PDI45			30002
#define MXT_DIN_LABPC			30003
#define MXT_DIN_EPICS			30004
#define MXT_DIN_NETWORK			30005
#define MXT_DIN_8255			30006

/* --- Digital output types --- */

#define MXT_DOU_SOFTWARE		40000
#define MXT_DOU_KS3063			40001
#define MXT_DOU_PDI45			40002
#define MXT_DOU_LABPC			40003
#define MXT_DOU_EPICS			40004
#define MXT_DOU_NETWORK			40005
#define MXT_DOU_8255			40006

/* --- Motor subclasses --- */

#define MXC_MTR_STEPPER			501
#define MXC_MTR_ANALOG			502

/* --- Motor types --- */

#define MXT_MTR_SOFTWARE		50000
#define MXT_MTR_E500			50001
#define MXT_MTR_SMC24			50002
#define MXT_MTR_PANTHER			50003
#define MXT_MTR_PDI40			50004
#define MXT_MTR_MMC32			50005
#define MXT_MTR_PM304			50006
#define MXT_MTR_EPICS			50007
#define MXT_MTR_MM3000			50008
#define MXT_MTR_MM4000			50009
#define MXT_MTR_PMAC			50010
#define MXT_MTR_PMAC_EPICS_TC		50011
#define MXT_MTR_APS_GAP			50012
#define MXT_MTR_COMPUMOTOR		50013
#define MXT_MTR_NETWORK			50014
#define MXT_MTR_GGCS			50015
#define MXT_MTR_D8			50016
#define MXT_MTR_VP9000			50017
#define MXT_MTR_AM9513			50018
#define MXT_MTR_HSC1			50019
#define MXT_MTR_E662			50020

   /* Pseudo motors. */

#define MXT_MTR_DAC_MOTOR		55001
#define MXT_MTR_ENERGY			55002
#define MXT_MTR_WAVELENGTH		55003
#define MXT_MTR_WAVENUMBER		55004
#define MXT_MTR_SLIT_MOTOR		55005
#define MXT_MTR_TRANSLATION		55006
#define MXT_MTR_XAFS_WAVENUMBER		55007
#define MXT_MTR_DELTA           	55008
#define MXT_MTR_ELAPSED_TIME		55009
#define MXT_MTR_MONOCHROMATOR		55010
#define MXT_MTR_LINEAR_FUNCTION		55011

#define MXT_MTR_S10ID			55101

/* --- Encoder types --- */

#define MXT_ENC_SOFTWARE		60000
#define MXT_ENC_KS3640			60001

/* --- Scaler types --- */

#define MXT_SCL_SOFTWARE		70000
#define MXT_SCL_QS450			70001
#define MXT_SCL_KS3610			70002
#define MXT_SCL_PDI45			70003
#define MXT_SCL_EPICS			70004
#define MXT_SCL_ORTEC974		70005
#define MXT_SCL_NETWORK			70006
#define MXT_SCL_AM9513			70007
#define MXT_SCL_MCS			70008

/* --- Timer types --- */

#define MXT_TIM_SOFTWARE		80000
#define MXT_TIM_RTC018			80001
#define MXT_TIM_PDI45			80002
#define MXT_TIM_EPICS			80003
#define MXT_TIM_ORTEC974		80004
#define MXT_TIM_NETWORK			80005
#define MXT_TIM_AM9513			80006

/* --- Amplifier types --- */

#define MXT_AMP_SOFTWARE		90000
#define MXT_AMP_NETWORK			90001
#define MXT_AMP_KEITHLEY428		90002

/* --- Relay types --- */

#define MXT_RLY_SOFTWARE		100000
#define MXT_RLY_NETWORK			100001
#define MXT_RLY_GENERIC			100002

/* --- Multichannel analyzer types --- */

#define MXT_MCA_SOFTWARE		110000
#define MXT_MCA_NETWORK			110001
#define MXT_MCA_EPICS			110002
#define MXT_MCA_TRUMP			110003

/* --- Multichannel scaler types --- */

#define MXT_MCS_SOFTWARE		120000
#define MXT_MCS_NETWORK			120001
#define MXT_MCS_EPICS			120002

/* --- Scan types --- */

#define MXS_LIN_INPUT 			201001
#define MXS_LIN_MOTOR			201002
#define MXS_LIN_2THETA			201003
#define MXS_LIN_SLIT			201004

#define MXS_LST_FILE			203001
#define MXS_LST_MEMORY			203002

#define MXS_XAF_STANDARD		205001

#define MXS_QUI_MCS			207001

#define MXS_QUI_JOERGER			207101
#define MXS_QUI_STRUCK			207102

/* --- Variable types --- */

#define MXV_INL_STRING			500001
#define MXV_INL_CHAR			500002
#define MXV_INL_UCHAR			500003
#define MXV_INL_SHORT			500004
#define MXV_INL_USHORT			500005
#define MXV_INL_INT			500006
#define MXV_INL_UINT			500007
#define MXV_INL_LONG			500008
#define MXV_INL_ULONG			500009
#define MXV_INL_FLOAT			500010
#define MXV_INL_DOUBLE			500011
#define MXV_INL_RECORD			500031

#define MXV_NET_STRING			501001
#define MXV_NET_CHAR			501002
#define MXV_NET_UCHAR			501003
#define MXV_NET_SHORT			501004
#define MXV_NET_USHORT			501005
#define MXV_NET_INT			501006
#define MXV_NET_UINT			501007
#define MXV_NET_LONG			501008
#define MXV_NET_ULONG			501009
#define MXV_NET_FLOAT			501010
#define MXV_NET_DOUBLE			501011
#define MXV_NET_RECORD			501031

#define MXV_EPI_STRING			502001
#define MXV_EPI_CHAR			502002
#define MXV_EPI_SHORT			502004
#define MXV_EPI_INT			502006
#define MXV_EPI_LONG			502008
#define MXV_EPI_FLOAT			502010
#define MXV_EPI_DOUBLE			502011

/* --- Server types --- */

#define MXN_NET_TCPIP			600001

/* --- Special types --- */

#define MXZ_GRP_STANDARD		700001

/* --- EPICS mailbox types --- */

#define MXM_EPICS_MOTOR_DB		910001

#endif /* __MX_DRIVR_H__ */
