/*
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

/*
 * Name:    mx_gpib.h
 *
 * Purpose: General header file for GPIB interfaces.
 */

#ifndef __MX_GPIB_H__
#define __MX_GPIB_H__

#include "mx_rec.h"

#define MX_NUM_GPIB_ADDRESSES	31

/* ======== GPIB interface flag values ======== */

#define MXF_GPIB_NOWAIT 1

/* ======== Generic GPIB interface data structure ======= */

typedef struct {
	MX_RECORD *record;

	int default_io_timeout_value;
	int default_eoi_mode;
	unsigned long default_read_terminator;
	unsigned long default_write_terminator;

	int open_semaphore[MX_NUM_GPIB_ADDRESSES];
	int secondary_address[MX_NUM_GPIB_ADDRESSES];

	int io_timeout_value[MX_NUM_GPIB_ADDRESSES];
	int eoi_mode[MX_NUM_GPIB_ADDRESSES];
	unsigned long read_terminator[MX_NUM_GPIB_ADDRESSES];
	unsigned long write_terminator[MX_NUM_GPIB_ADDRESSES];
} MX_GPIB;

#define MX_GPIB_STANDARD_FIELDS \
  {-1, -1, "default_io_timeout_value", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_GPIB, default_io_timeout_value), \
	{0}, NULL, MXFF_IN_DESCRIPTION}, \
  \
  {-1, -1, "default_eoi_mode", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_GPIB, default_eoi_mode), \
	{0}, NULL, MXFF_IN_DESCRIPTION}, \
  \
  {-1, -1, "default_read_terminator", MXFT_HEX, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_GPIB, default_read_terminator), \
	{0}, NULL, MXFF_IN_DESCRIPTION}, \
  \
  {-1, -1, "default_write_terminator", MXFT_HEX, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_GPIB, default_write_terminator), \
	{0}, NULL, MXFF_IN_DESCRIPTION}, \
  \
  {-1, -1, "open_semaphore", MXFT_INT, NULL, 1, {MX_NUM_GPIB_ADDRESSES}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_GPIB, open_semaphore), \
	{sizeof(int)}, NULL, 0}, \
  \
  {-1, -1, "secondary_address", MXFT_INT, NULL, 1, {MX_NUM_GPIB_ADDRESSES}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_GPIB, secondary_address), \
	{sizeof(int)}, NULL, 0}, \
  \
  {-1, -1, "io_timeout_value", MXFT_INT, NULL, 1, {MX_NUM_GPIB_ADDRESSES}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_GPIB, io_timeout_value), \
	{sizeof(int)}, NULL, 0}, \
  \
  {-1, -1, "eoi_mode", MXFT_INT, NULL, 1, {MX_NUM_GPIB_ADDRESSES}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_GPIB, eoi_mode), \
	{sizeof(int)}, NULL, 0}, \
  \
  {-1, -1, "read_terminator", MXFT_CHAR, NULL, 1, {MX_NUM_GPIB_ADDRESSES}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_GPIB, read_terminator), \
	{sizeof(char)}, NULL, 0}, \
  \
  {-1, -1, "write_terminator", MXFT_CHAR, NULL, 1, {MX_NUM_GPIB_ADDRESSES}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_GPIB, write_terminator), \
	{sizeof(char)}, NULL, 0}

/*
 * The structure type MX_GPIB_FUNCTION_LIST contains a list of
 * pointers to functions that vary from interface type to
 * interface type.
 */

typedef struct {
	mx_status_type ( *open_device ) ( MX_GPIB *gpib,
					int address );

	mx_status_type ( *close_device ) ( MX_GPIB *gpib,
					int address );

	mx_status_type ( *read_parms_from_device ) ( MX_GPIB *gpib,
					int address );

	mx_status_type ( *write_parms_to_device ) ( MX_GPIB *gpib,
					int address );

	mx_status_type ( *read ) ( MX_GPIB *gpib,
					int address,
					char *buffer,
					size_t max_bytes_to_read,
					size_t *bytes_read,
					int flags);

	mx_status_type ( *write ) ( MX_GPIB *gpib,
					int address,
					char *buffer,
					size_t bytes_to_write,
					size_t *bytes_written,
					int flags);

	mx_status_type ( *interface_clear ) ( MX_GPIB *gpib );

	mx_status_type ( *device_clear ) ( MX_GPIB *gpib );

	mx_status_type ( *selective_device_clear ) ( MX_GPIB *gpib,
					int address );

	mx_status_type ( *local_lockout ) ( MX_GPIB *gpib );

	mx_status_type ( *remote_enable ) ( MX_GPIB *gpib, int address );

	mx_status_type ( *go_to_local ) ( MX_GPIB *gpib, int address );

	mx_status_type ( *trigger ) ( MX_GPIB *gpib,
					int address );

	mx_status_type ( *wait_for_service_request ) ( MX_GPIB *gpib,
					double timeout );

	mx_status_type ( *serial_poll ) ( MX_GPIB *gpib,
					int address,
					unsigned char *serial_poll_byte );

	mx_status_type ( *serial_poll_disable ) ( MX_GPIB *gpib );
} MX_GPIB_FUNCTION_LIST;

/* ============== Initialization function. ============== */

MX_API mx_status_type mx_gpib_finish_record_initialization(
				MX_RECORD *gpib_record );

MX_API mx_status_type mx_gpib_get_pointers( MX_RECORD *gpib_record,
				MX_GPIB **gpib,
				MX_GPIB_FUNCTION_LIST **function_list_ptr,
				const char *calling_fname );

/* ============== Interface function prototypes. ============== */

MX_API mx_status_type mx_gpib_open_device( MX_RECORD *gpib_record,
					int address );

MX_API mx_status_type mx_gpib_close_device( MX_RECORD *gpib_record,
					int address );

MX_API mx_status_type mx_gpib_read_parms_from_device( MX_RECORD *gpib_record,
					int address );

MX_API mx_status_type mx_gpib_write_parms_to_device( MX_RECORD *gpib_record,
					int address );

MX_API mx_status_type mx_gpib_read( MX_RECORD *gpib_record,
					int address,
					char *buffer,
					size_t max_bytes_to_read,
					size_t *bytes_read,
					int flags );

MX_API mx_status_type mx_gpib_write( MX_RECORD *gpib_record,
					int address,
					char *buffer,
					size_t bytes_to_write,
					size_t *bytes_written,
					int flags );

MX_API mx_status_type mx_gpib_getline( MX_RECORD *gpib_record,
					int address,
					char *buffer,
					size_t max_bytes_to_read,
					size_t *bytes_read,
					int flags );

MX_API mx_status_type mx_gpib_putline( MX_RECORD *gpib_record,
					int address,
					char *buffer,
					size_t *bytes_written,
					int flags );

MX_API mx_status_type mx_gpib_interface_clear( MX_RECORD *gpib_record );

MX_API mx_status_type mx_gpib_device_clear( MX_RECORD *gpib_record );

MX_API mx_status_type mx_gpib_selective_device_clear( MX_RECORD *gpib_record,
					int address );

MX_API mx_status_type mx_gpib_local_lockout( MX_RECORD *gpib_record );

MX_API mx_status_type mx_gpib_remote_enable( MX_RECORD *gpib_record,
					int address );

MX_API mx_status_type mx_gpib_go_to_local( MX_RECORD *gpib_record,
					int address );

MX_API mx_status_type mx_gpib_trigger( MX_RECORD *gpib_record,
					int address );

MX_API mx_status_type mx_gpib_wait_for_service_request( MX_RECORD *gpib_record,
					double timeout );

MX_API mx_status_type mx_gpib_serial_poll( MX_RECORD *gpib_record,
					int address,
					unsigned char *serial_poll_byte );

MX_API mx_status_type mx_gpib_serial_poll_disable( MX_RECORD *gpib_record );

#endif /* __MX_GPIB_H__ */
