/*
 * Copyright 1999 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

/* mscan.c --- Scan routine for the simple motor scan program. */

#include <stdio.h>

#include "motor.h"
#include "mdialog.h"

int
motor_scan_fn( int argc, char *argv[] )
{
	MX_RECORD *record;
	MX_SCAN *scan;
	int status;
	mx_status_type mx_status;

	if ( argc != 3 ) {
		fprintf(output, "Usage: scan 'scan_name'.\n");
		return FAILURE;
	}

	/* Get the record for this scan name. */

	record = mx_get_record( motor_record_list, argv[2] );

	if ( record == (MX_RECORD *) NULL ) {
		fprintf( output,
			"No scan record named '%s' was found.\n", argv[2] );
		return FAILURE;
	}

	/* Is this a scan record? */

	if ( record->mx_superclass != MXR_SCAN ) {
		fprintf( output,
			"'%s' is not a scan record.  Record class = %ld\n",
			argv[2], record->mx_superclass );
		return FAILURE;
	}

	scan = (MX_SCAN *) (record->record_superclass_struct);

	if ( scan == (MX_SCAN *) NULL ) {
		fprintf( output,
			"MX_SCAN structure for scan '%s' is NULL.\n",
			argv[2] );
		return FAILURE;
	}

	/* Does the data file specified for this scan already exist? */

	status = motor_check_for_datafile_name_collision( scan );

	if ( status != SUCCESS )
		return status;

	/* Prompt for changes to the scan header. */

	status = motor_prompt_for_scan_header( scan );

	if ( status != SUCCESS )
		return status;

	fprintf( output, "*** Scan '%s' starting. ***\n", record->name );
	fprintf( output,
	"Press 'p' to pause the scan or any other key to abort the scan.\n" );

	/* Invoke the scan function. */

	mx_status = mx_perform_scan( scan );

	if ( mx_status.code != MXE_SUCCESS )
		return FAILURE;

	return SUCCESS;
}

mx_status_type
motor_scan_pause_request_handler( MX_SCAN *scan )
{
	const char fname[] = "motor_scan_pause_request_handler()";

	char buffer[80];
	int status, string_length;
	char command;

	fprintf( output, "\n*** The scan '%s' is paused. ***\n\n",
			scan->record->name );

	while (1) {
		fprintf( output,
		"Your choices are: (A)bort scan, (C)ontinue scan.\n" );

		string_length = sizeof(buffer);

		status = motor_get_string( output, "---> ", "C",
					&string_length, buffer );

		if ( status != SUCCESS ) {
			fprintf( output,
		"Unexpected error reading command string.  Trying again.\n" );

			continue;
		}

		command = '\0';

		switch( buffer[0] ) {
		case 'a':
		case 'A':
			command = 'A';
			break;
		case 'c':
		case 'C':
			command = 'C';
			break;
		default:
			fprintf( output,
				"Command '%s' not understood.  Try again.\n",
				buffer );
			break;
		}

		if ( command != '\0' )
			break;		/* Exit the while() loop. */
	}

	if ( command == 'A' ) {
		return mx_error( MXE_INTERRUPTED, fname, "Scan aborted." );
	} else {
		return MX_SUCCESSFUL_RESULT;
	}
}

